==> estateplat-common-1.2.4-20200424.061209-324-sources.jar: cn/gtmap/estateplat/model/server/core/BdcPpgxLog.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2020/2/26 0026
 * @description 不动产匹配关系表日志
 */
@Table(name = "bdc_ppgx_log")
public class BdcPpgxLog {
    @Id
    private String logid;//主键
    private String fwproid;//房屋项目ID
    private String fwbdcdyh;//房屋不动产单元号
    private String tdproid;//土地项目ID
    private String tdbdcdyh;//土地不动产单元号
    private String qjid;//权籍id
    private String bdcdyh;//不动产单元号
    private Date ppsj;//匹配时间
    private String czr;//匹配人

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getFwproid() {
        return fwproid;
    }

    public void setFwproid(String fwproid) {
        this.fwproid = fwproid;
    }

    public String getFwbdcdyh() {
        return fwbdcdyh;
    }

    public void setFwbdcdyh(String fwbdcdyh) {
        this.fwbdcdyh = fwbdcdyh;
    }

    public String getTdproid() {
        return tdproid;
    }

    public void setTdproid(String tdproid) {
        this.tdproid = tdproid;
    }

    public String getTdbdcdyh() {
        return tdbdcdyh;
    }

    public void setTdbdcdyh(String tdbdcdyh) {
        this.tdbdcdyh = tdbdcdyh;
    }

    public String getQjid() {
        return qjid;
    }

    public void setQjid(String qjid) {
        this.qjid = qjid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Date getPpsj() {
        return ppsj;
    }

    public void setPpsj(Date ppsj) {
        this.ppsj = ppsj;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }
}

==> estateplat-common-1.2.4-20210923.070020-887-sources.jar: cn/gtmap/estateplat/model/server/core/BdcPpgxLog.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2020/2/26 0026
 * @description 不动产匹配关系表日志
 */
@Table(name = "bdc_ppgx_log")
public class BdcPpgxLog {
    @Id
    private String logid;//主键
    private String fwproid;//房屋项目ID
    private String fwbdcdyh;//房屋不动产单元号
    private String tdproid;//土地项目ID
    private String tdbdcdyh;//土地不动产单元号
    private String qjid;//权籍id
    private String bdcdyh;//不动产单元号
    private Date ppsj;//匹配时间
    private String czr;//匹配人
    private String czlx;//操作类型 0：撤销匹配  1：匹配

    public String getLogid() {
        return logid;
    }

    public void setLogid(String logid) {
        this.logid = logid;
    }

    public String getFwproid() {
        return fwproid;
    }

    public void setFwproid(String fwproid) {
        this.fwproid = fwproid;
    }

    public String getFwbdcdyh() {
        return fwbdcdyh;
    }

    public void setFwbdcdyh(String fwbdcdyh) {
        this.fwbdcdyh = fwbdcdyh;
    }

    public String getTdproid() {
        return tdproid;
    }

    public void setTdproid(String tdproid) {
        this.tdproid = tdproid;
    }

    public String getTdbdcdyh() {
        return tdbdcdyh;
    }

    public void setTdbdcdyh(String tdbdcdyh) {
        this.tdbdcdyh = tdbdcdyh;
    }

    public String getQjid() {
        return qjid;
    }

    public void setQjid(String qjid) {
        this.qjid = qjid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Date getPpsj() {
        return ppsj;
    }

    public void setPpsj(Date ppsj) {
        this.ppsj = ppsj;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public String getCzlx() {
        return czlx;
    }

    public void setCzlx(String czlx) {
        this.czlx = czlx;
    }
}
